// Copyright 1994-2025 WIT.COM Inc Licensed GPL 3.0

package forgepb

import (
	"bytes"
	"io/ioutil"
	"net/http"
	"os"
	"os/user"

	"go.wit.com/log"
)

var forgeURL string = "https://go.wit.com/"

func (f *Forge) GetPatchesets() (*Patchsets, error) {
	url := forgeURL + "/GetPatchsets"
	log.Info("GetPatchsets() url", url)
	body, err := f.HttpPost(url, nil)
	if err != nil {
		log.Info("httpPost() failed:", err)
		return nil, err
	}
	log.Info("GetPatchets() len(body)", len(body))
	var psets *Patchsets
	psets = new(Patchsets)
	err = psets.Unmarshal(body)
	if err != nil {
		log.Info("Unmarshal failed", err)
		return nil, err
	}
	/*
		filename := filepath.Join("/tmp", pbfile)
		f, _ := os.OpenFile(filename, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0644)
		f.Write(body)
		f.Close()
	*/
	return psets, nil
}

func (f *Forge) HttpPost(url string, data []byte) ([]byte, error) {
	var err error
	var req *http.Request

	// data := []byte("some junk")
	// url := "https://go.wit.com/register/"

	req, err = http.NewRequest(http.MethodPost, url, bytes.NewBuffer(data))
	log.Info("httpPost() with len", len(data), "url", url)

	usr, _ := user.Current()
	req.Header.Set("author", usr.Username)
	hostname, _ := os.Hostname()
	req.Header.Set("hostname", hostname)

	client := &http.Client{}
	resp, err := client.Do(req)
	if err != nil {
		log.Error(err)
		return []byte("client.Do(req) error"), err
	}
	defer resp.Body.Close()
	log.Info("httpPost() with len", len(data))

	body, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		log.Error(err)
		return body, err
	}

	// test := strings.TrimSpace(string(body))
	// log.Info("go.wit.com returned body:", test)
	// if test == "OK" {
	// 	return body, nil
	// }

	return body, nil
}
